/******************************************************************************/
/*                                                                            */
/*       SAS Program to Join SAS Data Files into a Single SAS Data File       */
/*                           TIMSS 2007  User Guide                           */
/*                                                                            */
/******************************************************************************/

OPTIONS NONOTES ;

* Specify the file type ;
* <type> must be edited ;

%LET TYPE = <type> ;

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <path> must be edited ;

LIBNAME LIBDAT "<path>" ;

%MACRO DOIT ;

   * Specify the list of countries to be processed ;

   %IF %UPCASE(%SUBSTR(&TYPE,1,1)) = A %THEN %DO; * 4th grade countries ;

      %LET COUNTRY = DZA ARM AUS AUT TWN COL CZE DNK SLV ENG
                     GEO DEU HKG HUN IRN ITA JPN KAZ KWT LVA
                     LTU MNG MAR NLD NZL NOR QAT RUS SCO SGP
                     SVK SVN SWE TUN UKR USA YEM ADU CAB CBC
                     COT CQU UMA UMN ;

   %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,1,1)) = B %THEN %DO ; * 8th grade countries ;

      %LET COUNTRY = DZA ARM AUS BHR BIH BWA BGR TWN COL CYP
                     CZE EGY SLV ENG GEO GHA HKG HUN IDN IRN
                     ISR ITA JPN JOR KOR KWT LBN LTU MYS MLT
                     MNG MAR NOR OMN PSE QAT ROM RUS SAU SCO
                     SCG SGP SVN SWE SYR THA TUN TUR UKR USA
                     ADU BSQ CBC COT CQU UMA UMN ;

   %END;

   DATA &TYPE.ALLM4 ;
        SET %LET I = 1 ;
            %DO %WHILE(%LENGTH(%SCAN(&COUNTRY,&I))) ;
               %LET CTRY = %SCAN(&COUNTRY,&I) ;
                  LIBDAT.&TYPE&CTRY.M4
               %LET I = %EVAL(&I + 1) ;
            %END ; ;
   RUN ;

   * Specify the sorting variables ;
   * Dependent of the file type ;

   %LET SORTVARS = IDCNTRY IDSTUD ;

   %IF %UPCASE(%SUBSTR(&TYPE,2,1)) = C %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDSCHOOL ; %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,2,1)) = T %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDTEACH IDLINK ; %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,3,1)) = T %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDSTUD IDTEACH IDLINK ; %END ;

   PROC SORT DATA=&TYPE.ALLM4 OUT=LIBDAT.&TYPE.ALLM4 ;
        BY &SORTVARS ;
   RUN ;

%MEND DOIT ;

%DOIT ;
